@@ -42,8 +42,10 @@ GType anjuta_serializer_mode_get_type (void) G_GNUC_CONST;
 GType anjuta_vcs_status_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_VCS_STATUS (anjuta_vcs_status_get_type())
 /* enumerations from "gbf-project.h" */
-GType if_if_get_type (void) G_GNUC_CONST;
-#define ANJUTA_TYPE_IF (if_if_get_type())
+GType gbf_project_error_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_PROJECT_ERROR (gbf_project_error_get_type())
+GType gbf_project_capabilities_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_PROJECT_CAPABILITIES (gbf_project_capabilities_get_type())
 /* enumerations from "anjuta-project.h" */
 GType anjuta_project_node_type_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_PROJECT_NODE_TYPE (anjuta_project_node_type_get_type())
