@@ -1012,8 +1012,8 @@ anjuta_util_create_dir (const gchar* path)
 				NULL, NULL);
 		if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY)
 		{
-			g_message ("Warning: %s is a file. \n \
-					It is trying to be treated as a directory.",g_file_get_path (dir));
+			g_message ("Warning: %s is a file. \n "
+					"It is trying to be treated as a directory.",g_file_get_path (dir));
 			g_object_unref (dir);
 			return FALSE;
 		}
@@ -1462,7 +1462,25 @@ gboolean
 anjuta_util_is_project_file (const gchar *filename)
 {
 	gsize len = strlen (filename);
-	return (len > 8) && (strcmp (filename + len - 7, ".anjuta") == 0);
+	return ((len > 8) && (strcmp (filename + len - 7, ".anjuta") == 0));
+}
+
+/**
+ * anjuta_util_is_template_file:
+ * @filename: the file name
+ *
+ * Return TRUE if the file is an template project file. It is implemented by
+ * checking only the file extension. So it does not check the existence
+ * of the file. But it is working on an URI if it does not containt a
+ * fragment.
+ *
+ * Returns: TRUE if the file is a template file, else FALSE
+ */
+gboolean
+anjuta_util_is_template_file (const gchar *filename)
+{
+	gsize len = strlen (filename);
+	return ((len > 9) && (strcmp (filename + len - 8, ".wiz.tgz") == 0));
 }
 
 /**
@@ -2399,7 +2417,7 @@ anjuta_utils_drop_get_files (GtkSelectionData *selection_data)
 
 	for (i = 0; uris[i] != NULL; i++)
 	{
-		GFile* file = g_file_new_for_uri (uris[0]);
+		GFile* file = g_file_new_for_uri (uris[i]);
 		files = g_slist_append(files, file);
 	}
 
