@@ -51,10 +51,10 @@
 /* BOOLEAN:OBJECT (anjuta-marshal.list:1) */
 void
 anjuta_marshal_BOOLEAN__OBJECT (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
@@ -90,10 +90,10 @@ anjuta_marshal_BOOLEAN__OBJECT (GClosure     *closure,
 /* BOOLEAN:NONE (anjuta-marshal.list:2) */
 void
 anjuta_marshal_BOOLEAN__VOID (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
@@ -135,10 +135,10 @@ anjuta_marshal_BOOLEAN__VOID (GClosure     *closure,
 /* VOID:UINT64,UINT64 (anjuta-marshal.list:7) */
 void
 anjuta_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
-                                    GValue       *return_value,
+                                    GValue       *return_value G_GNUC_UNUSED,
                                     guint         n_param_values,
                                     const GValue *param_values,
-                                    gpointer      invocation_hint,
+                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT64_UINT64) (gpointer     data1,
@@ -172,10 +172,10 @@ anjuta_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
 /* VOID:BOOLEAN,POINTER (anjuta-marshal.list:8) */
 void
 anjuta_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
-                                      GValue       *return_value,
+                                      GValue       *return_value G_GNUC_UNUSED,
                                       guint         n_param_values,
                                       const GValue *param_values,
-                                      gpointer      invocation_hint,
+                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOOLEAN_POINTER) (gpointer     data1,
@@ -209,10 +209,10 @@ anjuta_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
 /* VOID:BOXED,BOXED (anjuta-marshal.list:9) */
 void
 anjuta_marshal_VOID__BOXED_BOXED (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_BOXED) (gpointer     data1,
@@ -246,10 +246,10 @@ anjuta_marshal_VOID__BOXED_BOXED (GClosure     *closure,
 /* VOID:OBJECT,CHAR (anjuta-marshal.list:10) */
 void
 anjuta_marshal_VOID__OBJECT_CHAR (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_CHAR) (gpointer     data1,
